searchData={"items":[{"type":"module","title":"Defrag","doc":"Provides a convenient macro for creating Ecto fragments with interpolation syntax.\n\nThis module offers the `defrag/1` macro that transforms string interpolation syntax\ninto Ecto fragment queries, making them more readable and maintainable.","ref":"Defrag.html"},{"type":"macro","title":"Defrag.defrag/1","doc":"Converts string interpolation syntax into an Ecto fragment.\n\nThis macro allows you to write Ecto fragments using familiar string interpolation\nsyntax (`#{...}`). It automatically converts the interpolation into proper\nEcto fragment parameters.","ref":"Defrag.html#defrag/1"},{"type":"macro","title":"Examples - Defrag.defrag/1","doc":"import Defrag\n\n    # Instead of writing:\n    fragment(\"date_part('year', ?)\", some_date)\n\n    # You can write:\n    defrag(\"date_part('year', #{some_date})\")\n\n    # Multiple interpolations are supported:\n    defrag(\"BETWEEN #{start_date} AND #{end_date}\")\n    # Becomes: fragment(\"BETWEEN ? AND ?\", start_date, end_date)","ref":"Defrag.html#defrag/1-examples"},{"type":"macro","title":"Usage in Ecto Queries - Defrag.defrag/1","doc":"import Ecto.Query\n    import Defrag\n\n    def users_born_in_year(query, year) do\n      from u in query,\n      where: defrag(\"date_part('year', #{u.birth_date}) = #{^year}\")\n    end","ref":"Defrag.html#defrag/1-usage-in-ecto-queries"},{"type":"macro","title":"Notes - Defrag.defrag/1","doc":"- The macro converts each interpolation (`#{...}`) into a parameter placeholder (`?`)\n- Variables used in interpolation must be in scope where the macro is called\n- The resulting fragment is safe against SQL injection as it uses Ecto's parameterization","ref":"Defrag.html#defrag/1-notes"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}